/*
This script adds support for RadiusNT v3 periodically checking the ServerPorts table via SNMP.
To enable it set 'SNMP' flag in the registry (HKEY_LOCAL_MACHINE\Software\IEA) to it's current value plus 4.
SNMPOnlineIntervalSecs controls how often to run the check.  The default is every 15 seconds.
When enabled SNMP concurrancy checking is disabled.
SNMPOnlineQueryIntervalMS controls how long to pause before running another snmp a query against the same NAS.
*/

CREATE PROCEDURE RadOnlineGetSNMP AS
Select s.IPAddress, s.ServerType, s.Community, sp.SNMPUser, sp.AcctSessionID, sp.Username, sp.ServerID,sp.Port
From Servers s, ServerPorts sp
Where s.ServerID = sp.ServerID
	AND AcctStatusType=1
	AND DATALENGTH(sp.SNMPUser) > 5
	AND DATALENGTH(s.Community) > 1
	AND Username IS NOT NULL
ORDER BY sp.Port
GO

CREATE PROCEDURE RadOnlineUpdateSNMP @serverid INT, @port INT, @username VARCHAR(32) AS
UPDATE ServerPorts SET AcctStatusType = 0
	WHERE AcctStatusType = 1 
	AND ServerID = @serverid
	AND Port = @port
	AND Username = @username
SELECT CASE WHEN @@rowcount = 0 THEN 'Not Updated' ELSE 'Updated' END AS Status
GO

