CREATE TABLE AccountTypes (
       AccountTypeID        NUMERIC(10,0) IDENTITY,
       AccountType          varchar(15) NOT NULL,
       Description          varchar(100) NOT NULL,
       DNISGroupID          NUMERIC(10,0) NULL,
       SortOrder            int DEFAULT 1  NOT NULL
)
go


ALTER TABLE AccountTypes
       ADD PRIMARY KEY (AccountTypeID)
go


CREATE TABLE Calls (
       NASIdentifier        varchar(16) NOT NULL,
       NASPort              varchar(10) DEFAULT (-1)  NOT NULL,
       AcctSessionID        varchar(16) NOT NULL,
       AcctStatusType       smallint NOT NULL,
       CallDate             smalldatetime DEFAULT getdate()  NOT NULL,
       UserName             varchar(40) NULL,
       AcctDelayTime        int DEFAULT 0  NULL,
       AcctSessionTime      int DEFAULT 0  NULL,
       FramedAddress        varchar(16) NULL,
       AcctTerminateCause   smallint NULL,
       AcctInputOctets      numeric(10,0) NULL,
       AccountID            NUMERIC(10,0) NULL,
       AcctOutputOctets     numeric(10,0) NULL,
       ServerID             NUMERIC(10,0) NULL,
       CallerID             varchar(15) NULL,
       ConnectInfo          varchar(32) NULL
)
go

CREATE INDEX iCallDate ON Calls
(
       CallDate
)
go

CREATE INDEX iUserName ON Calls
(
       UserName
)
go

CREATE INDEX iAccountID ON Calls
(
       AccountID
)
go

CREATE INDEX iServerID ON Calls
(
       ServerID
)
go


ALTER TABLE Calls
       ADD PRIMARY KEY (NASIdentifier, NASPort, AcctSessionID, 
              AcctStatusType)
go


CREATE TABLE DNISGroups (
       DNISGroupID          NUMERIC(10,0) IDENTITY,
       DNISGroup            varchar(25) NOT NULL,
       Description          varchar(45) NULL
)
go


ALTER TABLE DNISGroups
       ADD PRIMARY KEY (DNISGroupID)
go


CREATE TABLE DNISNumbers (
       DNISGroupID          NUMERIC(10,0) NOT NULL,
       DNISNumber           varchar(10) NOT NULL
)
go


ALTER TABLE DNISNumbers
       ADD PRIMARY KEY (DNISGroupID, DNISNumber)
go


CREATE TABLE Licenses (
       LicenseID            varchar(50) NOT NULL,
       Company              varchar(80) NOT NULL
)
go


ALTER TABLE Licenses
       ADD PRIMARY KEY (LicenseID)
go


CREATE TABLE MapAttributes (
       MapAttribute         varchar(32) NOT NULL,
       MapType              int NOT NULL,
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL
)
go


ALTER TABLE MapAttributes
       ADD PRIMARY KEY (MapAttribute, MapType)
go


CREATE TABLE MapValues (
       MapAttribute         varchar(32) NOT NULL,
       Value                varchar(32) NOT NULL,
       MapType              int NOT NULL,
       RadValue             int NOT NULL,
       Description          varchar(255) NULL
)
go


ALTER TABLE MapValues
       ADD PRIMARY KEY (MapAttribute, MapType, Value, RadValue)
go


CREATE TABLE MasterAccounts (
       CustomerID           NUMERIC(10,0) IDENTITY,
       FirstName            varchar(25) NULL,
       LastName             varchar(25) NULL,
       Active               smallint DEFAULT 1  NOT NULL,
       LastModifyUser       varchar(32) DEFAULT suser_name()  NULL,
       OverDue              smallint DEFAULT 0  NULL,
       Operator             varchar(32) DEFAULT suser_name()  NULL,
       StartDate            datetime DEFAULT getdate()  NULL,
       LastModifyDate       datetime DEFAULT getdate()  NULL,
       CreateDate           datetime DEFAULT getdate()  NULL,
       Comments             text NULL,
       CancelDate           datetime NULL
)
go

CREATE INDEX i_MasterAccounts_LastName ON MasterAccounts
(
       LastName
)
go


ALTER TABLE MasterAccounts
       ADD PRIMARY KEY (CustomerID)
go


CREATE TABLE Operators (
       Operator             varchar(15) NOT NULL,
       OperatorID           NUMERIC(10,0) IDENTITY,
       Password             varchar(15) NULL,
       Email                varchar(40) NULL,
       FirstName            varchar(25) NULL,
       LastName             varchar(25) NULL
)
go

CREATE UNIQUE INDEX iOperator ON Operators
(
       Operator
)
go


ALTER TABLE Operators
       ADD PRIMARY KEY (OperatorID)
go


CREATE TABLE RadATConfigs (
       AccountTypeID        NUMERIC(10,0) NOT NULL,
       RadATConfigID        NUMERIC(10,0) IDENTITY,
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL,
       Data                 varchar(100) NULL,
       Value                int NULL,
       RadCheck             smallint DEFAULT 0  NULL,
       Tag                  int NULL,
       LastModifyDate       datetime DEFAULT getdate()  NULL,
       LastModifyUser       varchar(32) DEFAULT suser_name()  NULL
)
go


ALTER TABLE RadATConfigs
       ADD PRIMARY KEY (RadATConfigID)
go


CREATE TABLE RadAttributes (
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL,
       Name                 varchar(32) NOT NULL,
       RadAttributeType     int NOT NULL,
       AliasAttributeID     int NULL,
       ReplyType            int DEFAULT 3  NULL,
       AliasVendorID        int NULL
)
go


ALTER TABLE RadAttributes
       ADD PRIMARY KEY (RadAttributeID, RadVendorID, RadVendorType)
go


CREATE TABLE RadConfigs (
       RadConfigID          NUMERIC(10,0) IDENTITY,
       AccountID            NUMERIC(10,0) NOT NULL,
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL,
       Data                 varchar(100) NULL,
       Value                int NULL,
       RadCheck             smallint DEFAULT 0  NULL,
       Tag                  int NULL,
       LastModifyDate       datetime DEFAULT getdate()  NULL,
       LastModifyUser       varchar(32) DEFAULT suser_name()  NULL
)
go


ALTER TABLE RadConfigs
       ADD PRIMARY KEY (RadConfigID)
go


CREATE TABLE RadIPAccountTypes (
       RadIPAccountTypeID   NUMERIC(10,0) IDENTITY,
       ServerGroupID        NUMERIC(10,0) NOT NULL,
       AccountTypeID        NUMERIC(10,0) NULL,
       RadIPGroupID         NUMERIC(10,0) NULL
)
go


CREATE TABLE RadIPAddresses (
       IPAddress            varchar(16) NOT NULL,
       RadIPGroupID         NUMERIC(10,0) NOT NULL,
       NASIdentifier        varchar(16) NULL,
       NASPort              varchar(10) NULL,
       LastUsed             datetime DEFAULT getdate()  NULL,
       State                int DEFAULT 0  NOT NULL
)
go

CREATE INDEX i_RadIPAddresses_NAS ON RadIPAddresses
(
       NASIdentifier,
       NASPort
)
go


ALTER TABLE RadIPAddresses
       ADD PRIMARY KEY (IPAddress)
go


CREATE TABLE RadIPGroups (
       RadIPGroupID         NUMERIC(10,0) IDENTITY,
       RadIPGroup           varchar(32) NOT NULL
)
go


ALTER TABLE RadIPGroups
       ADD PRIMARY KEY (RadIPGroupID)
go


CREATE TABLE RadLogMsgs (
       RadLogMsgID          int NOT NULL,
       Description          varchar(50) DEFAULT 'Undefined'  NOT NULL,
       Severity             int DEFAULT 0  NOT NULL
)
go


ALTER TABLE RadLogMsgs
       ADD PRIMARY KEY (RadLogMsgID)
go


CREATE TABLE RadLogs (
       RadLogMsgID          int NOT NULL,
       LogDate              smalldatetime DEFAULT getdate()  NOT NULL,
       UserName             varchar(40) NOT NULL,
       Data                 varchar(50) DEFAULT null  NULL,
       NASIdentifier        varchar(16) DEFAULT null  NULL,
       NASPort              varchar(10) NULL,
       CallerID             varchar(15) NULL
)
go


ALTER TABLE RadLogs
       ADD PRIMARY KEY (RadLogMsgID, LogDate, UserName)
go


CREATE TABLE RadProxyAttributeGroups (
       RadProxyAttributeGroupID NUMERIC(10,0) IDENTITY,
       RadRoamServerID      NUMERIC(10,0) NOT NULL,
       ProxyGroupName       varchar(32) NOT NULL,
       Priority             int DEFAULT 0  NOT NULL,
       Description          varchar(255) NULL
)
go


ALTER TABLE RadProxyAttributeGroups
       ADD PRIMARY KEY (RadProxyAttributeGroupID)
go


CREATE TABLE RadProxyAttributes (
       RadProxyAttributeID  NUMERIC(10,0) IDENTITY,
       RadProxyAttributeGroupID NUMERIC(10,0) NOT NULL,
       RadAttributeID       int NOT NULL,
       SearchType           smallint NOT NULL,
       String               varchar(253) NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL
)
go


ALTER TABLE RadProxyAttributes
       ADD PRIMARY KEY NONCLUSTERED (RadProxyAttributeGroupID, 
              SearchType, String, RadAttributeID, RadVendorID, 
              RadVendorType)
go


CREATE TABLE RadRejects (
       RadRejectID          NUMERIC(10,0) IDENTITY,
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL,
       Data                 varchar(100) NULL,
       Value                int NULL
)
go


ALTER TABLE RadRejects
       ADD PRIMARY KEY (RadRejectID)
go


CREATE TABLE RadRoamDomains (
       RadRoamDomainID      NUMERIC(10,0) IDENTITY,
       RadRoamServerID      NUMERIC(10,0) NOT NULL,
       Domain               varchar(32) NOT NULL,
       Priority             int DEFAULT 0  NOT NULL,
       AccountTypeID        NUMERIC(10,0) NULL
)
go


ALTER TABLE RadRoamDomains
       ADD PRIMARY KEY (RadRoamServerID, Domain)
go


CREATE TABLE RadRoamServers (
       RadRoamServerID      NUMERIC(10,0) IDENTITY,
       IPAddress            varchar(16) NULL,
       Server               varchar(32) NOT NULL,
       Secret               varchar(16) NOT NULL,
       Timeout              int NOT NULL,
       Retries              int NOT NULL,
       TreatAsLocal         smallint NOT NULL,
       StripDomain          smallint NOT NULL,
       AuthPort             int NULL,
       AcctPort             int NULL,
       RateTarget           int DEFAULT NULL  NULL,
       RateMax              int DEFAULT NULL  NULL
)
go


ALTER TABLE RadRoamServers
       ADD PRIMARY KEY (RadRoamServerID)
go


CREATE TABLE RadTriggers (
       RadTriggerID         NUMERIC(10,0) IDENTITY,
       AccountID            NUMERIC(10,0) NOT NULL,
       TriggerType          int NULL,
       FileName             varchar(64) NOT NULL,
       Parameters           varchar(64) NULL,
       Directory            varchar(128) NULL
)
go


ALTER TABLE RadTriggers
       ADD PRIMARY KEY (RadTriggerID)
go


CREATE TABLE RadValues (
       RadAttributeID       int NOT NULL,
       RadVendorID          int NOT NULL,
       RadVendorType        int DEFAULT 0  NOT NULL,
       Value                int NOT NULL,
       Name                 varchar(25) NOT NULL
)
go


ALTER TABLE RadValues
       ADD PRIMARY KEY (RadAttributeID, RadVendorID, RadVendorType, 
              Value)
go


CREATE TABLE RadVendors (
       RadVendorID          int NOT NULL,
       Name                 varchar(32) NOT NULL
)
go


ALTER TABLE RadVendors
       ADD PRIMARY KEY (RadVendorID)
go


CREATE TABLE ServerAccess (
       AccountTypeID        NUMERIC(10,0) NOT NULL,
       ServerID             NUMERIC(10,0) NOT NULL,
       StartTime            int DEFAULT 0  NULL,
       StopTime             int DEFAULT 0  NULL,
       MaxSessionLength     int DEFAULT 0  NULL,
       Port                 varchar(10) NULL
)
go


CREATE TABLE ServerGroups (
       ServerGroupID        NUMERIC(10,0) IDENTITY,
       ServerGroup          varchar(32) NOT NULL
)
go


ALTER TABLE ServerGroups
       ADD PRIMARY KEY (ServerGroupID)
go


CREATE TABLE ServerPorts (
       ServerID             NUMERIC(10,0) NOT NULL,
       Port                 varchar(10) NOT NULL,
       IPAddress            varchar(16) DEFAULT NULL  NULL,
       NASIdentifier        varchar(16) NOT NULL,
       MaxSessionTime       int DEFAULT 0  NULL,
       UserName             varchar(40) NULL,
       AcctSessionID        varchar(16) DEFAULT null  NULL,
       AcctStatusType       smallint DEFAULT null  NULL,
       CallDate             smalldatetime DEFAULT null  NULL,
       FramedAddress        varchar(16) DEFAULT null  NULL,
       AccountID            NUMERIC(10,0) NULL,
       SNMPUser             varchar(64) DEFAULT null  NULL,
       CallerID             varchar(15) DEFAULT null  NULL,
       ConnectInfo          varchar(32) DEFAULT null  NULL
)
go

ALTER TABLE ServerPorts
       ADD PRIMARY KEY (NASIdentifier, Port, ServerID)
go

CREATE TABLE Servers (
       ServerID             NUMERIC(10,0) IDENTITY,
       Server               varchar(25) NOT NULL,
       ServerType           int NULL,
       ServerGroupID        NUMERIC(10,0) NULL,
       IPAddress            varchar(16) NOT NULL,
       Comments             text NULL,
       Secret               varchar(16) DEFAULT null  NULL,
       RadRoamServerID      NUMERIC(10,0) DEFAULT null  NULL,
       Community            varchar(16) DEFAULT null  NULL
)
go

CREATE UNIQUE INDEX u_Servers_IPAddress ON Servers
(
       IPAddress
)
go


ALTER TABLE Servers
       ADD PRIMARY KEY (ServerID)
go


CREATE TABLE ServerTypes (
       ServerType           int NOT NULL,
       Vendor               varchar(32) NOT NULL,
       Model                varchar(32) NULL,
       SNMPType             int NULL,
       SNMPUser             varchar(64) NULL
)
go


ALTER TABLE ServerTypes
       ADD PRIMARY KEY (ServerType)
go


CREATE TABLE SubAccounts (
       AccountID            NUMERIC(10,0) IDENTITY,
       CustomerID           NUMERIC(10,0) NOT NULL,
       Active               smallint DEFAULT 1  NOT NULL,
       Login                varchar(32) NULL,
       Email                varchar(40) NULL,
       FirstName            varchar(25) NULL,
       LastName             varchar(25) NULL,
       AccountTypeID        NUMERIC(10,0) NOT NULL,
       Password             varchar(16) NULL,
       ExpireDate           datetime DEFAULT null  NULL,
       Extension            int DEFAULT 0  NULL,
       LoginLimit           smallint DEFAULT 0  NULL,
       TimeLeft             int DEFAULT null  NULL,
       LastModifyUser       varchar(32) DEFAULT suser_name()  NULL,
       LastUsed             datetime DEFAULT getdate()  NULL,
       LastModifyDate       datetime DEFAULT getdate()  NULL,
       Operator             varchar(32) DEFAULT suser_name()  NULL
)
go

CREATE INDEX i_SubAcconts_LastName ON SubAccounts
(
       LastName
)
go

CREATE INDEX i_SubAccounts_Login ON SubAccounts
(
       Login
)
go

CREATE INDEX i_SubAccounts_ExpireDate ON SubAccounts
(
       ExpireDate
)
go

CREATE INDEX i_SubAccounts_Email ON SubAccounts
(
       Email
)
go


ALTER TABLE SubAccounts
       ADD PRIMARY KEY (AccountID)
go


ALTER TABLE AccountTypes
       ADD FOREIGN KEY (DNISGroupID)
                             REFERENCES DNISGroups
go


ALTER TABLE DNISNumbers
       ADD FOREIGN KEY (DNISGroupID)
                             REFERENCES DNISGroups
go


ALTER TABLE MapAttributes
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE MapValues
       ADD FOREIGN KEY (MapAttribute, MapType)
                             REFERENCES MapAttributes
go


ALTER TABLE RadATConfigs
       ADD FOREIGN KEY (AccountTypeID)
                             REFERENCES AccountTypes
go


ALTER TABLE RadATConfigs
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE RadAttributes
       ADD FOREIGN KEY (RadVendorID)
                             REFERENCES RadVendors
go


ALTER TABLE RadConfigs
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE RadConfigs
       ADD FOREIGN KEY (AccountID)
                             REFERENCES SubAccounts
go


ALTER TABLE RadIPAccountTypes
       ADD FOREIGN KEY (ServerGroupID)
                             REFERENCES ServerGroups
go


ALTER TABLE RadIPAccountTypes
       ADD FOREIGN KEY (AccountTypeID)
                             REFERENCES AccountTypes
go


ALTER TABLE RadIPAccountTypes
       ADD FOREIGN KEY (RadIPGroupID)
                             REFERENCES RadIPGroups
go


ALTER TABLE RadIPAddresses
       ADD FOREIGN KEY (RadIPGroupID)
                             REFERENCES RadIPGroups
go


ALTER TABLE RadLogs
       ADD FOREIGN KEY (RadLogMsgID)
                             REFERENCES RadLogMsgs
go


ALTER TABLE RadProxyAttributes
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE RadProxyAttributes
       ADD FOREIGN KEY (RadProxyAttributeGroupID)
                             REFERENCES RadProxyAttributeGroups
go


ALTER TABLE RadRejects
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE RadRoamDomains
       ADD FOREIGN KEY (AccountTypeID)
                             REFERENCES AccountTypes
go


ALTER TABLE RadRoamDomains
       ADD FOREIGN KEY (RadRoamServerID)
                             REFERENCES RadRoamServers
go


ALTER TABLE RadTriggers
       ADD FOREIGN KEY (AccountID)
                             REFERENCES SubAccounts
go


ALTER TABLE RadValues
       ADD FOREIGN KEY (RadAttributeID, RadVendorID, RadVendorType)
                             REFERENCES RadAttributes
go


ALTER TABLE ServerAccess
       ADD FOREIGN KEY (ServerID)
                             REFERENCES Servers
go


ALTER TABLE ServerAccess
       ADD FOREIGN KEY (AccountTypeID)
                             REFERENCES AccountTypes
go


ALTER TABLE ServerPorts
       ADD FOREIGN KEY (ServerID)
                             REFERENCES Servers
go


ALTER TABLE Servers
       ADD FOREIGN KEY (ServerType)
                             REFERENCES ServerTypes
go


ALTER TABLE Servers
       ADD FOREIGN KEY (ServerGroupID)
                             REFERENCES ServerGroups
go


ALTER TABLE SubAccounts
       ADD FOREIGN KEY (CustomerID)
                             REFERENCES MasterAccounts
go

/* *********************************************************************************************** */

CREATE PROCEDURE RadRoamCache AS
Select Domain AS Label, Server, IPAddress, Secret, AuthPort, AcctPort,
Priority, Timeout, Retries, StripDomain, TreatAsLocal, at1.AccountType, rrs.RateTarget, rrs.RateMax
From RadRoamDomains rrd, RadRoamServers rrs, AccountTypes at1
	Where rrd.RadRoamServerID = rrs.RadRoamServerID
	AND rrd.AccountTypeID *= at1.AccountTypeID
UNION
Select rrd2.Domain AS Label, Server, IPAddress, Secret, AuthPort,
AcctPort, rrd.Priority, Timeout, Retries, StripDomain, TreatAsLocal,
at1.AccountType, rrs.RateTarget, rrs.RateMax
From RadRoamDomains rrd, RadRoamServers rrs, RadRoamDomains rrd2, AccountTypes at1
        Where rrd.RadRoamServerID = rrs.RadRoamServerID
        AND rrd.Domain = 'DEFAULT'
	AND rrd.AccountTypeID = at1.AccountTypeID
UNION
Select CONVERT(VARCHAR(5),RadRoamServerID) AS Label, Server, IPAddress,
Secret, AuthPort, AcctPort, 0, Timeout, Retries, StripDomain,
TreatAsLocal, NULL, NULL, NULL
From RadRoamServers
Order By Label,Priority
GO

CREATE PROCEDURE RadGetRejects AS
Select ra.RadAttributeID, Name, Data, Value, ra.RadAttributeType, rr.RadVendorID, rr.RadVendorType
From RadAttributes ra, RadRejects rr
Where ra.RadAttributeID=rr.RadAttributeID
        AND ra.RadVendorID = rr.RadVendorID
        AND ra.RadVendorType = rr.RadVendorType
ORDER BY Data,Value
GO

CREATE Procedure RadGetProxyAttributes AS
SELECT apg.RadProxyAttributeGroupID,apg.RadRoamServerID,ap.String,ap.SearchType,ap.RadAttributeID
FROM RadProxyAttributeGroups apg, RadProxyAttributes ap
	WHERE apg.RadProxyAttributeGroupID = ap.RadProxyAttributeGroupID
ORDER BY apg.Priority ASC, apg.RadProxyAttributeGroupID
GO

CREATE PROCEDURE RadSetLastUsed AS
CREATE TABLE #tmpusers
(
AccountID INT,
CallDate DATETIME
)

INSERT INTO #tmpusers (AccountID,CallDate)
SELECT AccountID,MAX(CallDate) 
FROM Calls 
	WHERE CallDate > DATEADD(dd,-1,getdate())
GROUP BY AccountID

UPDATE SubAccounts
SET LastUsed = t.CallDate
FROM SubAccounts sa, #tmpusers t
	WHERE sa.AccountID = t.AccountID

DROP TABLE #tmpusers
GO

CREATE PROCEDURE RadAtCache @accounttype VARCHAR(16) AS
SELECT at1.AccountType, ra.RadAttributeID, Name, Data, Value, ra.RadAttributeType, rc.RadVendorID, rc.RadVendorType, rc.RadCheck, rc.Tag, at1.AccountTypeID
FROM RadATConfigs rc, RadAttributes ra, AccountTypes at1
	WHERE ra.RadAttributeID = rc.RadAttributeID
	AND rc.AccountTypeID = at1.AccountTypeID
	AND (ra.RadVendorID = rc.RadVendorID OR rc.RadVendorID IS NULL)
	AND (ra.RadVendorType = rc.RadVendorType OR rc.RadVendorType IS NULL)
	AND (@accounttype IS NULL OR at1.AccountType = @accounttype)
ORDER BY AccountType, rc.RadATConfigID
GO

CREATE PROCEDURE RadServerAccessCache AS
Select MaxSessionLength, StartTime, StopTime, s.IPAddress, sa.Port, at1.AccountType
From Servers s, ServerAccess sa, AccountTypes at1
	WHERE s.ServerID = sa.ServerID
	AND sa.AccountTypeID = at1.AccountTypeID
GO

CREATE PROCEDURE RadDNISCache AS
Select at1.AccountType, dn.DNISNumber
FROM AccountTypes at1, DNISNumbers dn
	WHERE at1.DNISGroupID = dn.DNISGroupID
GO

CREATE PROCEDURE RadCheckTrigger @AccountID int AS
Select FileName, Parameters, Directory, TriggerType from RadTriggers Where AccountID=@AccountID
GO

CREATE PROCEDURE RadGetConfigs @AccountID int AS
Select ra.RadAttributeID, Name, Data, Value, ra.RadAttributeType, rc.RadVendorID, rc.RadVendorType, rc.RadCheck, rc.Tag
From RadConfigs rc, RadAttributes ra
Where ra.RadAttributeID=rc.RadAttributeID
	AND ra.RadVendorID = rc.RadVendorID
	AND ra.RadVendorType = rc.RadVendorType
	AND rc.AccountID=@AccountID
ORDER BY rc.RadConfigID
GO

CREATE PROCEDURE RadGetCacheUsers @date DATETIME, @flag SMALLINT AS
IF (@flag = 1)
BEGIN
SELECT sa.AccountID, sa.Login, sa.Password, NULL, at1.AccountType, sa.LoginLimit, sa.TimeLeft * 60,
MasterExpire=CASE WHEN CancelDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',CancelDate) END,
SubExpire=CASE WHEN ExpireDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',DATEADD(Day,sa.Extension+ma.OverDue,ExpireDate)) END,
0 AS OverLimit, CASE WHEN sa.Active = 0 OR ma.Active = 0 THEN 0 ELSE CASE WHEN ma.StartDate IS NULL THEN 1 ELSE DATEDIFF(ss,'19700101',ma.StartDate) END END AS StartDate
FROM SubAccounts sa, MasterAccounts ma, AccountTypes at1
	WHERE sa.CustomerID = ma.CustomerID
	AND sa.AccountTypeID = at1.AccountTypeID
	AND sa.Login <> ''
	AND (sa.LastModifyDate > @date OR ma.LastModifyDate > @date)
END ELSE IF (@flag = 2)
BEGIN
SELECT sa.AccountID, sa.Login, sa.Password, NULL, at1.AccountType, sa.LoginLimit, sa.TimeLeft * 60,
MasterExpire=CASE WHEN CancelDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',CancelDate) END,
SubExpire=CASE WHEN ExpireDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',DATEADD(Day,sa.Extension+ma.OverDue,ExpireDate)) END,
0 AS OverLimit, CASE WHEN sa.Active = 0 OR ma.Active = 0 THEN 0 ELSE CASE WHEN ma.StartDate IS NULL THEN 1 ELSE DATEDIFF(ss,'19700101',ma.StartDate) END END AS StartDate
FROM SubAccounts sa, MasterAccounts ma, AccountTypes at1
	WHERE sa.CustomerID = ma.CustomerID
	AND sa.AccountTypeID = at1.AccountTypeID
	AND sa.Login <> ''
	AND (sa.LastUsed > @date OR sa.LastUsed IS NULL)
END
GO

CREATE PROCEDURE RadGetUser @user VARCHAR(64) , @password VARCHAR(32) AS
SELECT sa.AccountID, sa.Login, sa.Password, NULL, at1.AccountType, sa.LoginLimit, sa.TimeLeft * 60, 
MasterExpire=CASE WHEN CancelDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',CancelDate) END,
SubExpire=CASE WHEN ExpireDate IS NULL THEN NULL ELSE DATEDIFF(Day,'19700101',DATEADD(Day,sa.Extension+ma.OverDue,ExpireDate)) END,
0 AS OverLimit, CASE WHEN sa.Active = 0 OR ma.Active = 0 THEN 0 ELSE CASE WHEN ma.StartDate IS NULL THEN 1 ELSE DATEDIFF(ss,'19700101',ma.StartDate) END END AS StartDate
FROM SubAccounts sa, MasterAccounts ma, AccountTypes at1
        WHERE sa.CustomerID = ma.CustomerID
	AND sa.AccountTypeID = at1.AccountTypeID
        AND sa.Login = @user
GO

CREATE PROCEDURE RadCheckOnline @UserName varchar(64), @accountid INT AS
Select Count(*) From ServerPorts WHERE (((AccountID IS NULL OR @accountid IS NULL) AND UserName=@UserName) OR (AccountID IS NOT NULL AND AccountID=@accountid)) AND AcctStatusType IN (1,3) AT ISOLATION READ UNCOMMITTED
GO

CREATE PROCEDURE RadCheckOnlineSNMP @UserName varchar(64), @accountid INT AS 
SELECT s.IPAddress, st.SNMPType, s.Community, sp.SNMPUser, sp.AcctSessionID
FROM Servers s, ServerPorts sp, ServerTypes st
	WHERE (((sp.AccountID IS NULL OR @accountid IS NULL) AND sp.UserName=@UserName) 
		OR (sp.AccountID IS NOT NULL AND sp.AccountID=@accountid)) 
	AND sp.AcctStatusType IN (1,3)
	AND s.ServerType = st.ServerType
	AND s.ServerID = sp.ServerID
	AND sp.SNMPUser IS NOT NULL
	AND s.Community IS NOT NULL

AT ISOLATION READ UNCOMMITTED
GO

/* Dictionary and Sample Data */
SET IDENTITY_INSERT AccountTypes ON
INSERT INTO AccountTypes (AccountTypeID,AccountType,Description,DNISGroupID,SortOrder) VALUES(1,'PPP',  'PPP Dialup', NULL,1)
INSERT INTO AccountTypes (AccountTypeID,AccountType,Description,DNISGroupID,SortOrder) VALUES(2,'ISDN', 'ISDN', NULL,2)
SET IDENTITY_INSERT AccountTypes OFF


INSERT INTO RadVendors (RadVendorID,Name) VALUES(0, 'RADIUS Standard')

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(01, 0, 0, 'User-Name', 		0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(02, 0, 0, 'Password', 		0,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(03, 0, 0, 'Challenge-Response',	0)
/* INSERT RadAttributes VALUES(04, 0, 0, 'NAS-IP-Address', 	2) */
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(04, 0, 0, 'NAS-Identifier', 	2,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(05, 0, 0, 'NAS-Port', 		1,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(06, 0, 0, 'User-Service', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(07, 0, 0, 'Framed-Protocol', 	1,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(08, 0, 0, 'Framed-Address', 	2,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(09, 0, 0, 'Framed-Netmask', 	2,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(10, 0, 0, 'Framed-Routing', 	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(11, 0, 0, 'Framed-Filter', 		0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(12, 0, 0, 'Framed-MTU', 		1,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(13, 0, 0, 'Framed-Compression', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(14, 0, 0, 'Login-Host', 		2,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(15, 0, 0, 'Login-Service', 		1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(16, 0, 0, 'Login-TCP-Port', 	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(17, 0, 0, 'Change-Password', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(18, 0, 0, 'Reply-Message', 		0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(19, 0, 0, 'Callback-Number', 	0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(20, 0, 0, 'Callback-Name', 		0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(21, 0, 0, 'Expiration', 		3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(22, 0, 0, 'Framed-Route', 		0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(23, 0, 0, 'Framed-IPX-Network', 	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(24, 0, 0, 'State', 			0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(25, 0, 0, 'Class', 			0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 0, 0, 'Vendor-Specific', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(27, 0, 0, 'Session-Timeout', 	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(28, 0, 0, 'Idle-Timeout', 		1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(29, 0, 0, 'Termination-Action', 	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(30, 0, 0, 'NAS-Port-DNIS', 		0,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(31, 0, 0, 'Caller-Id', 		0,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(32, 0, 0, 'NAS-Identifier', 	0,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(33, 0, 0, 'Proxy-State',		0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(34, 0, 0, 'Login-LAT-Service', 	0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(35, 0, 0, 'Login-LAT-Node', 	0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(36, 0, 0, 'Login-LAT-Group', 	0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(37, 0, 0, 'Framed-AppleTalk-Link',	1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(38, 0, 0, 'Framed-AppleTalk-Network',1,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(39, 0, 0, 'Framed-AppleTalk-Zone', 	0,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(40, 0, 0, 'Acct-Status-Type', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(41, 0, 0, 'Acct-Delay-Time', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(42, 0, 0, 'Acct-Input-Octets', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(43, 0, 0, 'Acct-Output-Octets', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(44, 0, 0, 'Acct-Session-Id', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(45, 0, 0, 'Acct-Authentic', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(46, 0, 0, 'Acct-Session-Time', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(47, 0, 0, 'Acct-Input-Packets', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(48, 0, 0, 'Acct-Output-Packets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(49, 0, 0, 'Acct-Terminate-Cause',1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(50, 0, 0, 'Acct-Multi-Session-Id',0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(51, 0, 0, 'Acct-Link-Count',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(52, 0, 0, 'Acct-Input-Gigawords',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(53, 0, 0, 'Acct-Output-Gigawords',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(55, 0, 0, 'Event-Time',		3)
GO

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(60, 0, 0, 'CHAP-Challenge', 	0,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(61, 0, 0, 'NAS-Port-Type', 		1,2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(62, 0, 0, 'Port-Limit', 		1,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(63, 0, 0, 'Login-LAT-Port',		0,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(64, 0, 0, 'Tunnel-Type',		11,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(65, 0, 0, 'Tunnel-Medium-Type', 	11,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(66, 0, 0, 'Tunnel-Client-Endpoint',	10,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(67, 0, 0, 'Tunnel-Server-Endpoint',	10,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(68, 0, 0, 'Tunnel-Connection', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(69, 0, 0, 'Tunnel-Password', 		10,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(70, 0, 0, 'ARAP-Password', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(71, 0, 0, 'ARAP-Features', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(72, 0, 0, 'ARAP-Zone-Access', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(73, 0, 0, 'ARAP-Security', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(74, 0, 0, 'ARAP-Security-Data', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(75, 0, 0, 'Password-Retry', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(76, 0, 0, 'Prompt', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(77, 0, 0, 'Connect-Info', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(78, 0, 0, 'Configuration-Token', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(79, 0, 0, 'EAP-Message', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(80, 0, 0, 'Message-Authenticator',	0)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(81, 0, 0, 'Tunnel-Private-Group-ID',	10,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(82, 0, 0, 'Tunnel-Assignment-ID',	10,1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(83, 0, 0, 'Tunnel-Preference',	11,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(84, 0, 0, 'ARAP-Challenge-Response',0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(85, 0, 0, 'Acct-Interim-Interval',  0)

/*
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(90, 0, 0, 'Tunnel-Client-Auth-ID',	10,3)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType,ReplyType) VALUES(91, 0, 0, 'Tunnel-Server-Auth-ID',	10,3)
*/

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(90, 0, 0, 'Ascend-Filter', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(91, 0, 0, 'Ascend-Telnet-Profile',		0)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(120, 0, 0, 'Ascend-Modem-PortNo', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(121, 0, 0, 'Ascend-Modem-SlotNo', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(122, 0, 0, 'Ascend-Modem-ShelfNo', 		1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(128, 0, 0, 'Ascend-Shared-Prof-Enable', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(133, 0, 0, 'Ascend-BACP-Enable',	 	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(172, 0, 0, 'Ascend-Base-Channel-Count', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(176, 0, 0, 'Ascend-Backup',	 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(187, 0, 0, 'Ascend-Multilink-ID',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(188, 0, 0, 'Ascend-Num-In-Multilink',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(189, 0, 0, 'Ascend-First-Dest',		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(190, 0, 0, 'Ascend-Pre-Input-Octets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(191, 0, 0, 'Ascend-Pre-Output-Octets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(192, 0, 0, 'Ascend-Pre-Input-Packets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(193, 0, 0, 'Ascend-Pre-Output-Packets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(194, 0, 0, 'Ascend-Maximum-Time',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(195, 0, 0, 'Ascend-Disconnect-Cause',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(196, 0, 0, 'Ascend-Connect-Progress',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(197, 0, 0, 'Ascend-Data-Rate',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(198, 0, 0, 'Ascend-PreSession-Time',	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(199, 0, 0, 'Ascend-Token-Idle', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(200, 0, 0, 'Ascend-Token-Immediate', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(201, 0, 0, 'Ascend-Require-Auth', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(202, 0, 0, 'Ascend-Number-Sessions', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(203, 0, 0, 'Ascend-Authen-Alias', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(204, 0, 0, 'Ascend-Token-Expiry', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(205, 0, 0, 'Ascend-Menu-Selector', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(206, 0, 0, 'Ascend-Menu-Item', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(207, 0, 0, 'Ascend-PW-Warntime', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(208, 0, 0, 'Ascend-PW-Lifetime', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(209, 0, 0, 'Ascend-IP-Direct', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(210, 0, 0, 'Ascend-PPP-VJ-Slot-Comp', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(211, 0, 0, 'Ascend-PPP-VJ-1172', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(212, 0, 0, 'Ascend-PPP-Async-Map', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(213, 0, 0, 'Ascend-Third-Prompt', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(214, 0, 0, 'Ascend-Send-Secret', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(215, 0, 0, 'Ascend-Receive-Secret', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(216, 0, 0, 'Ascend-IPX-Peer-Mode', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(217, 0, 0, 'Ascend-IP-Pool-Definition', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(218, 0, 0, 'Ascend-Assign-IP-Pool', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(219, 0, 0, 'Ascend-FR-Direct', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(220, 0, 0, 'Ascend-FR-Direct-Profile', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(221, 0, 0, 'Ascend-FR-Direct-DLCI', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(222, 0, 0, 'Ascend-Handle-IPX', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(223, 0, 0, 'Ascend-Netware-timeout', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(224, 0, 0, 'Ascend-IPX-Alias', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(225, 0, 0, 'Ascend-Metric', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(226, 0, 0, 'Ascend-PRI-Number-Type', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(227, 0, 0, 'Ascend-Dial-Number', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(228, 0, 0, 'Ascend-Route-IP', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(229, 0, 0, 'Ascend-Route-IPX', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(230, 0, 0, 'Ascend-Bridge', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(231, 0, 0, 'Ascend-Send-Auth', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(232, 0, 0, 'Ascend-Send-Passwd', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(233, 0, 0, 'Ascend-Link-Compression', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(234, 0, 0, 'Ascend-Target-Util', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(235, 0, 0, 'Ascend-Maximum-Channels', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(236, 0, 0, 'Ascend-Inc-Channel-Count', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(237, 0, 0, 'Ascend-Dec-Channel-Count', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(238, 0, 0, 'Ascend-Seconds-Of-History', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(239, 0, 0, 'Ascend-History-Weigh-Type', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(240, 0, 0, 'Ascend-Add-Seconds', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(241, 0, 0, 'Ascend-Remove-Seconds', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(242, 0, 0, 'Ascend-Data-Filter', 		4)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(243, 0, 0, 'Ascend-Call-Filter', 		4)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(244, 0, 0, 'Ascend-Idle-Limit', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(245, 0, 0, 'Ascend-Preempt-Limit', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(246, 0, 0, 'Ascend-Callback', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(247, 0, 0, 'Ascend-Data-Svc', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(248, 0, 0, 'Ascend-Force-56', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(249, 0, 0, 'Ascend-Billing-Number', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(250, 0, 0, 'Ascend-Call-By-Call', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(251, 0, 0, 'Ascend-Transit-Number', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(252, 0, 0, 'Ascend-Host-Info', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(253, 0, 0, 'Ascend-PPP-Address', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(254, 0, 0, 'Ascend-MPP-Idle-Percent', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(255, 0, 0, 'Ascend-Xmit-Rate', 		1)
GO

/* RadValues */

/* 'AttributeID','Name', 'Value' */
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 1, 'Login-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 2, 'Framed-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 3, 'Dialback-Login-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 4, 'Dialback-Framed-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 5, 'Dialout-Framed-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 6, 'Shell-User')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 7, 'NAS-Prompt')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 8, 'Authenticate-Only')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0, 9, 'Dialback-NAS-Prompt')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0,10, 'Call-Check')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(6, 0, 0,11, 'Callback-Admin')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 1, 'PPP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 2, 'SLIP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 3, 'ARAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 4, 'Grandalf')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 5, 'Xylogics-IPX-Slip')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 6, 'X75')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 256, 'MPP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 257, 'EURAW')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 258, 'EUUI')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 259, 'X25')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 260, 'COMB')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(7, 0, 0, 261, 'FR')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(10, 0, 0, 0, 'None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(10, 0, 0, 1, 'Broadcast')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(10, 0, 0, 2, 'Listen')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(10, 0, 0, 3, 'Broadcast-Listen')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(13, 0, 0, 0, 'None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(13, 0, 0, 1, 'Van-Jacobsen-TCP-IP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(13, 0, 0, 2, 'IP header compression')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(13, 0, 0, 3, 'Stac-LZS compression')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 0, 'Telnet')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 1, 'Rlogin')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 2, 'TCP-Clear')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 3, 'PortMaster')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 4, 'LAT')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 5, 'X25-PAD')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 6, 'X25-T3POS')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(15, 0, 0, 8, 'TCP-No-Message')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(40, 0, 0, 1, 'Start')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(40, 0, 0, 2, 'Stop')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(40, 0, 0, 3, 'Interim-Update')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(40, 0, 0, 7, 'Accounting-On')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(40, 0, 0, 8, 'Accounting-Off')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(45, 0, 0, 0, 'None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(45, 0, 0, 1, 'RADIUS')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(45, 0, 0, 2, 'Local')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 1, 'User-Request')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 2, 'Lost-Carrier')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 3, 'Lost-Service')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 4, 'Idle-Timeout')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 5, 'Session-Timeout')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 6, 'Admin-Reset')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 7, 'Admin-Reboot')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 8, 'Port-Error')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 9, 'NAS-Error')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 10, 'NAS-Request')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 11, 'NAS-Reboot')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 12, 'Port-Unneeded')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 13, 'Port-Preempted')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 14, 'Port-Suspended')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 15, 'Service-Unavailable')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 16, 'Callback')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 17, 'User-Error')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(49, 0, 0, 18, 'Host-Request')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 0, 'Async')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 1, 'Sync')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 2, 'ISDN')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 3, 'ISDN-V120')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 4, 'ISDN-V110')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 5, 'Virtual')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 6, 'PIAFS')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 7, 'HDLC-Clear-Channel')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 8, 'X25')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0, 9, 'X75')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,10, 'G3-Fax')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,11, 'SDSL')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,12, 'ADSL-CAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,13, 'ADSL-DMT')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,14, 'IDSL')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,15, 'Ethernet')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,16, 'xDSL')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,17, 'Cable')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,18, 'Wireless-Other')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(61,  0, 0,19, 'Wireless-IEE80211')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 1, 'PPTP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 2, 'L2F')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 3, 'L2TP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 4, 'ATMP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 5, 'VTP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 6, 'AH')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 7, 'IP-IP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 8, 'MIN-IP-IP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 9, 'ESP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 10, 'GRE')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 11, 'DVS')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(64,  0, 0, 12, 'IP-in-IP Tunneling')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 1, 'IPV4')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 2, 'IPV6')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 3, 'NSAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 4, 'HDLC')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 5, 'BBN 1822')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 6, '802')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 7, 'E.163')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 8, 'E.164')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 9, 'F.69 (Telix)')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 10, 'X.121 (X.25 FR)')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 11, 'IPX')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 12, 'Appletalk')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 13, 'Decnet IV')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 14, 'Banyan Vines')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(65,  0, 0, 15, 'E.164 /w NSAP subaddress')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(200, 0, 0, 0, 'Tok-Imm-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(200, 0, 0, 1, 'Tok-Imm-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(201, 0, 0, 0, 'Not-Require-Auth')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(201, 0, 0, 1, 'Require-Auth')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(207, 0, 0, 0, 'Days-Of-Warning')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(208, 0, 0, 0, 'Lifetime-In-Days')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(210, 0, 0, 1, 'VJ-Slot-Comp-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(211, 0, 0, 1, 'PPP-VJ-1172')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(219, 0, 0, 0, 'FR-Direct-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(219, 0, 0, 1, 'FR-Direct-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(222, 0, 0, 0, 'Handle-IPX-None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(222, 0, 0, 1, 'Handle-IPX-Client')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(222, 0, 0, 2, 'Handle-IPX-Server')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(216, 0, 0, 0, 'IPX-Peer-Router')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(216, 0, 0, 1, 'IPX-Peer-Dialin')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(226, 0, 0, 0, 'Unknown-Number')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(226, 0, 0, 1, 'Intl-Number')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(226, 0, 0, 2, 'National-Number')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(226, 0, 0, 4, 'Local-Number')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(226, 0, 0, 5, 'Abbrev-Number')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(228, 0, 0, 0, 'Route-IP-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(228, 0, 0, 1, 'Route-IP-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(229, 0, 0, 0, 'Route-IPX-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(229, 0, 0, 1, 'Route-IPX-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(230, 0, 0, 0, 'Bridge-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(230, 0, 0, 1, 'Bridge-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(231, 0, 0, 0, 'Send-Auth-None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(231, 0, 0, 1, 'Send-Auth-PAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(231, 0, 0, 2, 'Send-Auth-CHAP')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(233, 0, 0, 0, 'Link-Comp-None')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(233, 0, 0, 1, 'Link-Comp-Stac')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(239, 0, 0, 0, 'History-Constant')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(239, 0, 0, 1, 'History-Linear')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(239, 0, 0, 2, 'History-Quadratic')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(246, 0, 0, 0, 'Callback-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(246, 0, 0, 1, 'Callback-Yes')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 0, 'Switched-Voice-Bearer')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 1, 'Switched-56KR')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 2, 'Switched-64K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 3, 'Switched-64KR')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 4, 'Switched-56K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 5, 'Switched-384KR')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 6, 'Switched-384K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 7, 'Switched-1536K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 8, 'Switched-1536KR')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 9, 'Switched-128K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 10, 'Switched-192K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 11, 'Switched-256K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 12, 'Switched-320K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 13, 'Switched-384K-MR')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 14, 'Switched-448K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 15, 'Switched-512K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 16, 'Switched-576K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 17, 'Switched-640K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 18, 'Switched-704K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 19, 'Switched-768K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 20, 'Switched-832K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 21, 'Switched-896K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 22, 'Switched-960K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 23, 'Switched-1024K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 24, 'Switched-1088K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 25, 'Switched-1152K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 26, 'Switched-1216K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 27, 'Switched-1280K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 28, 'Switched-1344K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 29, 'Switched-1408K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 30, 'Switched-1472K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 31, 'Switched-1600K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 32, 'Switched-1664K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 33, 'Switched-1728K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 34, 'Switched-1792K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 35, 'Switched-1856K')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(247, 0, 0, 36, 'Switched-1920K')

INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(248, 0, 0, 0, 'Force-56-No')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(248, 0, 0, 1, 'Force-56-Yes')
GO
/* Below are some Vendors and Vendor Specific Attributes */

INSERT INTO RadVendors (RadVendorID,Name) VALUES(5, 'ACC')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 1, 'Acc-Reason-Code', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 2, 'Acc-CCP-Option', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 3, 'Acc-Input-Errors', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 4, 'Acc-Output-Errors', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 5, 'Acc-Ccp-Option', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 6, 'Acc-Customer-Id', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 7, 'Acc-Ip-Gateway-Pri', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 8, 'Acc-Ip-Gateway-Sec', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 9, 'Acc-Route-Policy', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 10, 'Acc-ML-MLX-Admin-State',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 11, 'Acc-ML-Call-Threshold', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 12, 'Acc-ML-Clear-Threshold', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 13, 'Acc-ML-Damping-Factor', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 14, 'Acc-Tunnel-Secret', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 17, 'Acc-Service-Profile', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 18, 'Acc-Request-Type', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 19, 'Acc-Bridging-Support', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 20, 'Acc-VPSM-Oversubscribed', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 21, 'Acc-Acct-On-Off-Reason', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 22, 'Acc-Tunnel-Port',	 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 23, 'Acc-Dns-Server-Pri', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 24, 'Acc-Dns-Server-Sec', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 25, 'Acc-Nbns-Server-Pri', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 5, 26, 'Acc-Nbns-Server-Sec', 		2)

INSERT INTO RadVendors (RadVendorID,Name) VALUES(9, 'Cisco')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9,   1, 'Cisco-AVPair', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 2, 'Cisco-NAS-Port',			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 187, 'Multilink-ID', 			1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 188, 'Num-In-Multilink', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 190, 'Pre-Input-Octets', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 191, 'Pre-Output-Octets', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 192, 'Pre-Input-Packets', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 193, 'Pre-Output-Packets', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 195, 'Disconnect-Cause', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 197, 'Data-Rate',	 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 198, 'PreSession-Time', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 250, 'Account-Info', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 251, 'Service-Info', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 252, 'Command-Code', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 9, 253, 'Control-Info', 		0)
GO

INSERT INTO RadVendors(RadVendorID, Name) VALUES(  61, 'Merit')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 144, 'Reply-If-Ack-Message', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 145, 'LAS-Start-Time', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 146, 'LAS-Code', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 147, 'LAS-Duration', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 148, 'Local-Duration', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 149, 'Huntgroup-Service', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 150, 'Port-Entry', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 211, 'Proxy-Action', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 213, 'Token', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 219, 'Ownership', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 220, 'Subgroup', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 221, 'Huntgroup-Name', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 222, 'User-Id', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 61, 223, 'User-Realm', 		0)
GO

INSERT INTO RadVendors(RadVendorID, Name) VALUES( 307, 'Livingston')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307,  2, 'LE-Terminate-Detail', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307,  3, 'LE-Advice-of-Change', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307,  4, 'LE-Connect-Detail', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307,  5, 'LE-SA-ID',	 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307,  9, 'LE-IPSec-Log-Options', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307, 10, 'LE-IPSec-Policy-Deny', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307, 11, 'LE-IPSec-Active-Profile', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307, 12, 'LE-IPSec-Outsource-Profile', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 307, 13, 'LE-IPSec-Passive-Profile', 	0)
GO

INSERT INTO RadVendors (RadVendorID,Name) VALUES(311,'Microsoft')
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-Response',311,0,1,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-Error',311,0,2,NULL)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-CPW-1',311,0,3,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-CPW-2',311,0,4,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-LM-Enc-PW',311,0,5,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-NT-Enc-PW',311,0,6,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-MPPE-Encryption-Policy',311,1,7,1)
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 7, 1, 'Encryption-Allowed')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 7, 2, 'Encryption-Required')

INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-MPPE-Encryption-Type',311,1,8,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-RAS-Vendor',311,1,9,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-Challenge',311,0,11,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP-MPPE-Keys',311,0,12,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-BAP-Usage',311,0,13,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Link-Utilization-Threshold',311,1,14,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Link-Drop-Time-Limit',311,1,15,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-MPPE-Send-Key',311,0,16,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-MPPE-Recv-Key',311,0,17,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-RAS-Version',311,0,18,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Old-ARAP-Password',311,0,19,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-New-ARAP-Password',311,0,20,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-ARAP-PW-Change-Reason',311,1,21,NULL)
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 21, 1, 'Just-Change-Password')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 21, 2, 'Expired-Password')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 21, 3, 'Admin-Req-Pass-Change')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 21, 4, 'Password-Too-Short')

INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Filter',311,0,22,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Acct-Auth-Type',311,1,23,NULL)
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 23, 1, 'PAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 23, 2, 'CHAP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 23, 3, 'MS-CHAP-1')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 23, 4, 'MS-CHAP-2')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 23, 5, 'EAP')
GO

INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Acct-EAP-Type',311,0,24,NULL)
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 24, 4, 'MD5')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 24, 5, 'OTP')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 24, 6, 'Generic Token Card')
INSERT INTO RadValues (RadAttributeID,RadVendorID,RadVendorType,Value,Name) VALUES(26, 311, 24, 13, 'TLS')

INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP2-Response',311,0,25,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP2-Success',311,0,26,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-CHAP2-CPW',311,0,27,2)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Primary-DNS-Server',311,0,28,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Secondary-DNS-Server',311,0,29,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Primary-NBNS-Server',311,0,30,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-Secondary-NBNS-Server',311,0,31,1)
INSERT INTO RadAttributes (RadAttributeID,Name,RadVendorID,RadAttributeType,RadVendorType,ReplyType) VALUES(26,'MS-ARAP-Challenge',311,0,33,2)
GO

INSERT INTO RadVendors (RadVendorID,Name) VALUES(429, '3Com/USR')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429,   108, 'Modulation_Type',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429,   153, 'Simplified_MNP_Levels',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429,   199, 'Simplified_V42bis_Usage',	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36864, 'IP-Input-Filter', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36867, 'IP-Output-Filter', 		0)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36872, 'IES-Next-Hop-Gateway', 	2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36879, 'Primary-DNS-Server', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36880, 'Secondary-DNS-Server',		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36881, 'Primary-NBNS-Server', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36882, 'Secondary-NBNS-Server',	2)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36889, 'Chasis-Call-Slot',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36890, 'Chasis-Call-Span',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36891, 'Chasis-Call-Channel',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36893, 'Unauthenticated_Time',	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36899, 'Connect-Speed',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36900, 'Framed-IP-Address-Pool-Name',	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36901, 'MP-EDO',			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 36902, 'Local-Framed-IP-Addr',	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38913, 'Speed_Of_Connection', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38914, 'Max_Channels', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38918, 'Compression_Algorithm',	1)
GO

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38931, 'Send-Name', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38932, 'Send-Password', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38933, 'Start-Time', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38934, 'End-Time', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38949, 'Local-IP-Address', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38950, 'Routing-Protocol', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38951, 'Modem-Group',	 	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38959, 'MP_MRRU',			1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38977, 'MP-EDO-HIPER',		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38978, 'Modem-Training-Time',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38979, 'Interface_Index',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 38998, 'VTS-Session-Key',		0)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 39000, 'Call-Arrival-Time',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 39001, 'Call-End-Time',		1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 48733, 'Channel-Connected-To', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 48734, 'Slot-Connected-To', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 429, 48735, 'Device-Connected-To', 	1)
GO

INSERT INTO RadVendors(RadVendorID, Name) VALUES( 529, 'Ascend')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 90, 'Ascend-Filter', 			0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 91, 'Ascend-Telnet-Profile',		0)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 120, 'Ascend-Modem-PortNo', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 121, 'Ascend-Modem-SlotNo', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 122, 'Ascend-Modem-ShelfNo', 		1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 128, 'Ascend-Shared-Profile-Enable', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 133, 'Ascend-BACP-Enable',	 	1)

INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 187, 'Ascend-Multilink-ID',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 188, 'Ascend-Num-In-Multilink',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 189, 'Ascend-First-Dest',		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 190, 'Ascend-Pre-Input-Octets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 191, 'Ascend-Pre-Output-Octets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 192, 'Ascend-Pre-Input-Packets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 193, 'Ascend-Pre-Output-Packets',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 194, 'Ascend-Maximum-Time',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 195, 'Ascend-Disconnect-Cause',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 196, 'Ascend-Connect-Progress',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 197, 'Ascend-Data-Rate',		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 198, 'Ascend-PreSession-Time',	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 199, 'Ascend-Token-Idle', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 200, 'Ascend-Token-Immediate', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 201, 'Ascend-Require-Auth', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 202, 'Ascend-Number-Sessions', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 203, 'Ascend-Authen-Alias', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 204, 'Ascend-Token-Expiry', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 205, 'Ascend-Menu-Selector', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 206, 'Ascend-Menu-Item', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 207, 'Ascend-PW-Warntime', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 208, 'Ascend-PW-Lifetime', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 209, 'Ascend-IP-Direct', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 210, 'Ascend-PPP-VJ-Slot-Comp', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 211, 'Ascend-PPP-VJ-1172', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 212, 'Ascend-PPP-Async-Map', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 213, 'Ascend-Third-Prompt', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 214, 'Ascend-Send-Secret', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 215, 'Ascend-Receive-Secret', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 216, 'Ascend-IPX-Peer-Mode', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 217, 'Ascend-IP-Pool-Definition', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 218, 'Ascend-Assign-IP-Pool', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 219, 'Ascend-FR-Direct', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 220, 'Ascend-FR-Direct-Profile', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 221, 'Ascend-FR-Direct-DLCI', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 222, 'Ascend-Handle-IPX', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 223, 'Ascend-Netware-timeout', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 224, 'Ascend-IPX-Alias', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 225, 'Ascend-Metric', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 226, 'Ascend-PRI-Number-Type', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 227, 'Ascend-Dial-Number', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 228, 'Ascend-Route-IP', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 229, 'Ascend-Route-IPX', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 230, 'Ascend-Bridge', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 231, 'Ascend-Send-Auth', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 232, 'Ascend-Send-Passwd', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 233, 'Ascend-Link-Compression', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 234, 'Ascend-Target-Util', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 235, 'Ascend-Maximum-Channels', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 236, 'Ascend-Inc-Channel-Count', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 237, 'Ascend-Dec-Channel-Count', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 238, 'Ascend-Seconds-Of-History', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 239, 'Ascend-History-Weigh-Type', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 240, 'Ascend-Add-Seconds', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 241, 'Ascend-Remove-Seconds', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 242, 'Ascend-Data-Filter', 		4)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 243, 'Ascend-Call-Filter', 		4)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 244, 'Ascend-Idle-Limit', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 245, 'Ascend-Preempt-Limit', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 246, 'Ascend-Callback', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 247, 'Ascend-Data-Svc', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 248, 'Ascend-Force-56', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 249, 'Ascend-Billing-Number', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 250, 'Ascend-Call-By-Call', 		1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 251, 'Ascend-Transit-Number', 	0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 252, 'Ascend-Host-Info', 		0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 253, 'Ascend-PPP-Address', 		2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 254, 'Ascend-MPP-Idle-Percent', 	1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 529, 255, 'Ascend-Xmit-Rate', 		1)
GO

INSERT INTO RadVendors(RadVendorID, Name) VALUES(1584, 'Bay-Networks')
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 28, 'Annex-Filter', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 29, 'Annex-CLI-Command', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 30, 'Annex-CLI-Filter', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 31, 'Annex-Host-Restrict', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 32, 'Annex-Host-Allow', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 33, 'Annex-Product-Name', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 34, 'Annex-SW-Version', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 35, 'Annex-Local-IP-Address', 2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 36, 'Annex-Callback-Portlist', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 37, 'Annex-Sec-Profile-Index', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 38, 'Annex-Tunnel-Authen-Type', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 39, 'Annex-Tunnel-Authen-Mode', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 40, 'Annex-Authen-Servers', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 41, 'Annex-Acct-Servers', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 42, 'Annex-User-Server-Location', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 43, 'Annex-Local-Username', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 44, 'Annex-System-Disc-Reason', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 45, 'Annex-Modem-Disc-Reason', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 46, 'Annex-Disconnect-Reason', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 47, 'Annex-Addr-Resolution-Protocol', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 48, 'Annex-Addr-Resolution-Servers', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 49, 'Annex-Domain-Name', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 50, 'Annex-Transmit-Speed', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 51, 'Annex-Receive-Speed', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 52, 'Annex-Input-Filter', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 53, 'Annex-Output-Filter', 0)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 54, 'Annex-Primary-DNS-Server', 2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 55, 'Annex-Secondary-DNS-Server', 2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 56, 'Annex-Primary-NBNS-Server', 2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 57, 'Annex-Secondary-NBNS-Server', 2)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 59, 'Annex-Keypress-Timeout', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 60, 'Annex-Unauthenticated-Time', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 61, 'Annex-Re-CHAP-Timeout', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 62, 'Annex-MRRU', 1)
INSERT INTO RadAttributes (RadAttributeID,RadVendorID,RadVendorType,Name,RadAttributeType) VALUES(26, 1584, 63, 'Annex-EDO', 0)
GO

INSERT INTO RadATConfigs (AccountTypeID,RadAttributeID,RadVendorID,RadVendorType,Data,Value,RadCheck) VALUES(1, 6, 0, 0, '2', 2, 0)	
INSERT INTO RadATConfigs (AccountTypeID,RadAttributeID,RadVendorID,RadVendorType,Data,Value,RadCheck) VALUES(1, 7, 0, 0, '1', 1, 0)

INSERT INTO RadATConfigs (AccountTypeID,RadAttributeID,RadVendorID,RadVendorType,Data,Value,RadCheck) VALUES(2, 6, 0, 0, '2', 2, 0)	
INSERT INTO RadATConfigs (AccountTypeID,RadAttributeID,RadVendorID,RadVendorType,Data,Value,RadCheck) VALUES(2, 7, 0, 0, '1', 1, 0)	

INSERT INTO Servers (Server,IPAddress,Comments,Secret,RadRoamServerID) VALUES('localhost', '127.0.0.1', 'localhost', 'localhost', NULL)
INSERT INTO ServerPorts (ServerID,Port,NASIdentifier,IPAddress,MaxSessionTime,UserName,AcctStatusType,CallDate,FramedAddress) VALUES(1, '0', '127.0.0.1',NULL, 0, NULL, 0, NULL, NULL)
GO

INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 0, 'Generic',    'Start at 0', 	0, NULL)
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 1, 'Generic',    'Start at 1',	0, NULL)
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 2, 'Livingston', 'Portmaster 2',	0, '.1.3.6.1.4.1.307.3.2.1.1.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 3, 'Livingston', 'Portmaster 3',	0, '.1.3.6.1.4.1.307.3.2.1.1.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 4, 'Livingston', 'Portmaster 4',	0, '.1.3.6.1.4.1.307.3.2.1.1.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 5, 'Ascend',     'Max 4000 T1',	1, '.1.3.6.1.4.1.529.12.3.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 6, 'Ascend',     'Max 4000 E1',	1, '.1.3.6.1.4.1.529.12.3.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 7, 'Ascend',     'MAX 1800 BRI',	1, '.1.3.6.1.4.1.529.12.3.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 8, 'Ascend',     'MAX TNT',	1, '.1.3.6.1.4.1.529.12.3.1.4.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES( 9, 'Cisco',      'AS5200',	0, '.1.3.6.1.4.1.9.2.9.2.1.18.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES(10, 'USR',        'Total Control',0, NULL)
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES(11, 'CompuTone',  'PowerRack',	0, NULL)
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES(12, 'Microcom',   '6000',		0, NULL)
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES(13, 'USR',	'HyperARC',	0, '.1.3.6.1.4.1.429.4.10.1.1.18.')
INSERT INTO ServerTypes(ServerType, Vendor, Model, SNMPType, SNMPUser) VALUES(14, 'Nortel',	'Nortel 5399',	0, '.1.3.6.1.4.1.15.2.16.1.2.1.3.1.')
GO

INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(0, 'Generic Message', 0)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(1, 'Generic Error', 5)

INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(10, 'User Not Found', 3)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(11, 'Bad Password', 3)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(12, 'User Expired', 2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(13, 'User OverDue', 2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(14, 'Over Login Limit', 1)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(15, 'No Time Left', 1)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(16, 'Port Not Allowed', 2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(17, 'Reject Attribute',2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(18, 'Check Attribute', 2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(19, 'No Attributes', 3)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(20, 'User Inactive', 2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(21, 'Start Date not reached',2)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(40, 'SNMP Check Failed', 1)

INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(50, 'Bad Request', 4)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(51, 'No UserName', 4)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(52, 'No Password', 4)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(53, 'Bad Digest', 6)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(54, 'Bad username', 3)

INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(60, 'Parse Error', 5)
INSERT INTO RadLogMsgs (RadLogMsgID,Description,Severity) VALUES(100, 'Chap Not Allowed', 5)
GO

INSERT INTO MasterAccounts (FirstName, LastName, Active, CancelDate, OverDue) 
	VALUES('Test', 'Test', 1, NULL, 0)
INSERT INTO SubAccounts (CustomerID, Active, Login, Email, FirstName, LastName, AccountTypeID, Password, ExpireDate, Extension, LoginLimit, TimeLeft)
	VALUES(1, 1, 'test', NULL, 'Test', 'Test', 1, 'test', NULL, 0, 1, NULL)
GO

CREATE TRIGGER MA_Update ON MasterAccounts
FOR UPDATE
AS
UPDATE MasterAccounts SET LastModifyDate = getdate()
FROM MasterAccounts ma, inserted i
	WHERE ma.CustomerID = i.CustomerID
GO

CREATE TRIGGER SA_Update ON SubAccounts
FOR UPDATE
AS
Update SubAccounts
Set sa.LastModifyDate = GetDate()
From SubAccounts sa, inserted i
Where sa.AccountID = i.AccountID
GO

CREATE TRIGGER SA_Update2 ON RadConfigs
FOR INSERT, UPDATE
AS
UPDATE SubAccounts
Set sa.LastModifyDate = GetDate()
From SubAccounts sa, inserted i
Where sa.AccountID = i.AccountID
GO

CREATE TRIGGER calls_insert ON Calls 
FOR INSERT
AS
DECLARE @ast int, @serverid NUMERIC(10,0)

SELECT @serverid = ServerID FROM inserted i
IF @serverid IS NULL
	SELECT @serverid = s.ServerID FROM Servers s, inserted i WHERE s.IPAddress = i.NASIdentifier

Select @ast = AcctStatusType From inserted

UPDATE RadIPAddresses SET State = CASE WHEN @ast = 1 OR @ast = 3 THEN 2 WHEN @ast = 2 THEN 0 ELSE State END
FROM RadIPAddresses ri, inserted i
	WHERE ri.NASPort = i.NASPort
	AND ri.NASIdentifier = i.NASIdentifier

UPDATE ServerPorts
        Set UserName = i.UserName,
		sp.AccountID = i.AccountID,
                sp.AcctStatusType = i.AcctStatusType,
		sp.CallDate = i.CallDate,
		sp.CallerID = i.CallerID,
		sp.ConnectInfo = i.ConnectInfo,
		sp.FramedAddress = i.FramedAddress
        FROM ServerPorts sp, inserted i
        	WHERE sp.Port = i.NASPort
		AND sp.NASIdentifier = i.NASIdentifier
		AND (i.CallDate >= sp.CallDate OR sp.CallDate IS NULL)

IF (@@rowcount = 0)
	BEGIN
	/* SNMPUser should add the port for all except 10 (ascend) */
	INSERT INTO ServerPorts (ServerID,Port,NASIdentifier,IPAddress,MaxSessionTime,UserName,AcctStatusType,CallDate,FramedAddress)

	SELECT @serverid,i.NASPort,i.NASIdentifier,NULL,0,i.UserName,i.AcctStatusType,i.CallDate,i.FramedAddress
	FROM inserted i
	        WHERE NOT EXISTS (SELECT * FROM ServerPorts sp WHERE i.NASPort = sp.Port AND sp.NASIdentifier = i.NASIdentifier)

	DELETE FROM ServerPorts WHERE CallDate < DATEADD(dd,-7,getdate()) AND SNMPUser IS NULL
	END

if @ast = 2
	BEGIN
	/* Stuff we only do on stop records */
        UPDATE SubAccounts
        Set sa.TimeLeft = sa.TimeLeft - ((i.AcctSessionTime + (60 - (i.AcctSessionTime % 60))) / 60)
        FROM SubAccounts sa, inserted i
        WHERE ((i.AccountID IS NOT NULL AND sa.AccountID = i.AccountID) OR (i.AccountID IS NULL AND sa.Login = i.UserName))
		and sa.TimeLeft IS NOT NULL
		and i.AcctStatusType = 2
	END
GO

/* LDAP Attributes */
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(3,1,0,'Challenge-Response')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(4,1,0,'NAS-IP-Address')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(5,1,0,'NAS-Port')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(6,1,0,'User-Service')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(7,1,0,'Framed-Protocol')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(8,1,0,'Framed-Address')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(9,1,0,'Framed-Netmask')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(10,1,0,'Framed-Routing')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(11,1,0,'Framed-Filter')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(12,1,0,'Framed-MTU')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(13,1,0,'Framed-Compression')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(14,1,0,'Login-Host')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(15,1,0,'Login-Service')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(16,1,0,'Login-TCP-Port')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(17,1,0,'Change-Password')
go

INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(18,1,0,'Reply-Message')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(19,1,0,'Callback-Number')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(20,1,0,'Callback-Name')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(21,1,0,'Expiration')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(22,1,0,'Framed-Route')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(23,1,0,'Framed-IPX-Network')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(24,1,0,'State')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(25,1,0,'Class')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(26,1,0,'Vendor-Specific')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(27,1,0,'Session-Timeout')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(28,1,0,'Idle-Timeout')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(29,1,0,'Termination-Action')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(30,1,0,'NAS-Port-DNIS')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(31,1,0,'Caller-Id')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(32,1,0,'NAS-Identifier')
go

INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(33,1,0,'Proxy-State')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(34,1,0,'Login-LAT-Service')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(35,1,0,'Login-LAT-Node')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(36,1,0,'Login-LAT-Group')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(37,1,0,'Framed-AppleTalk-Link')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(38,1,0,'Framed-AppleTalk-Network')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(39,1,0,'Framed-AppleTalk-Zone')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(40,1,0,'Acct-Status-Type')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(41,1,0,'Acct-Delay-Time')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(42,1,0,'Acct-Input-Octets')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(43,1,0,'Acct-Output-Octets')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(44,1,0,'Acct-Session-Id')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(45,1,0,'Acct-Authentic')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(46,1,0,'Acct-Session-Time')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(47,1,0,'Acct-Input-Packets')
go

INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(48,1,0,'Acct-Output-Packets')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(49,1,0,'Acct-Terminate-Cause')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(50,1,0,'Acct-Multi-Session-ID')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(51,1,0,'Acct-Link-Count')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(52,1,0,'Acct-Input-Gigawords')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(53,1,0,'Acct-Output-Gigawords')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(55,1,0,'Event-Time')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(60,1,0,'CHAP-Challenge')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(61,1,0,'NAS-Port-Type')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(62,1,0,'Port-Limit')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(63,1,0,'Login-LAT-Port')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(64,1,0,'Tunnel-Type')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(65,1,0,'Tunnel-Medium-Type')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(66,1,0,'Tunnel-Client-Endpoint')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(67,1,0,'Tunnel-Server-Endpoirt')
go

INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(68,1,0,'Tunnel-Connection')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(69,1,0,'Tunnel-Password')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(70,1,0,'ARAP-Password')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(71,1,0,'ARAP-Features')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(72,1,0,'ARAP-Zone-Access')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(73,1,0,'ARAP-Security')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(74,1,0,'ARAP-Security-Data')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(75,1,0,'Password-Retry')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(76,1,0,'Prompt')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(77,1,0,'Connect-Info')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(78,1,0,'Configuration-Token')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(79,1,0,'EAP-Message')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(80,1,0,'Signature')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(81,1,0,'Tunnel-Private-Group-ID')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(82,1,0,'Tunnel-Assignment-ID')
go

INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(83,1,0,'Tunnel-Preference')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(84,1,0,'ARAP-Challenge-Response')
INSERT INTO MapAttributes (RadAttributeID,MapType,RadVendorID,MapAttribute) VALUES(85,1,0,'Acct-Interim-Interval')


/* LDAP Values */
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',1,NULL,'Login-User')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',2,NULL,'Framed-User')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',3,NULL,'Callback-Login')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',4,NULL,'Callback-Framed')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',5,NULL,'Outbound')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',6,NULL,'Administrative')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',7,NULL,'NAS-Prompt')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',8,NULL,'Authenicate-Only')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',9,NULL,'Callback-NAS-Prompt')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'User-Service',129,NULL,'Call-Check-User')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',1,NULL,'PPP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',2,NULL,'SLIP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',3,NULL,'ARA')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',4,NULL,'Gandalf')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',5,NULL,'Xylogics')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',256,NULL,'MPP')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',257,NULL,'EURAW')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',258,NULL,'EUUI')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',8,NULL,'X25')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',260,NULL,'COMB')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Protocol',261,NULL,'FR')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Routing',0,NULL,'None')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Routing',1,NULL,'Broadcast')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Routing',2,NULL,'Listen')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Routing',3,NULL,'Broadcast-Listen')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Compression',0,NULL,'None')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Compression',1,NULL,'Van-Jacobsen-TCP-IP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Framed-Compression',2,NULL,'IPX-Header-Compression')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',0,NULL,'Telnet')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',1,NULL,'Rlogin')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',2,NULL,'TCP-Clear')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',3,NULL,'PortMaster')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',4,NULL,'LAT')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',5,NULL,'X25-PAD')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Login-Service',6,NULL,'X25-T3POS')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Termination-Action',0,NULL,'Default')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Termination-Action',1,NULL,'RADIUS-Request')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',1,NULL,'Start')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',2,NULL,'Stop')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',3,NULL,'Alive')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',4,NULL,'Modem-Start')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',5,NULL,'Modem-Stop')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',6,NULL,'Cancel')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',7,NULL,'Accounting-On')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Status-Type',8,NULL,'Accounting-Off')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Authentic',0,NULL,'None')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Authentic',1,NULL,'RADIUS')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Authentic',2,NULL,'Local')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',1,NULL,'User-Request')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',2,NULL,'Lost-Carrier')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',3,NULL,'Lost-Service')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',4,NULL,'Idle-Timeout')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',5,NULL,'Session-Timeout')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',6,NULL,'Admin-Reset')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',7,NULL,'Admin-Reboot')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',8,NULL,'Port-Error')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',9,NULL,'NAS-Error')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',10,NULL,'NAS-Request')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',11,NULL,'NAS-Reboot')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',12,NULL,'Port-Unneeded')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',13,NULL,'Port-Preempted')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',14,NULL,'Port-Suspended')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',15,NULL,'Service-Unavailable')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',16,NULL,'Callback')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',17,NULL,'User-Error')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Acct-Terminate-Cause',18,NULL,'Host-Request')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',0,NULL,'Async')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',1,NULL,'Sync')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',2,NULL,'ISDN')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',3,NULL,'ISDN-V120')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',4,NULL,'ISDN-V110')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',5,NULL,'Virtual')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',6,NULL,'PAIFS')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',7,NULL,'HDLC-Clear-Channel')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',8,NULL,'X25')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'NAS-Port-Type',9,NULL,'X75')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',1,NULL,'PPTP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',2,NULL,'L2F')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',3,NULL,'L2TP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',4,NULL,'ATMP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',5,NULL,'VTP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',6,NULL,'AH')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',7,NULL,'IP-IP-Encap')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',8,NULL,'MIN-IP-IP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',9,NULL,'ESP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',10,NULL,'PPTP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',11,NULL,'DVS')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Type',12,NULL,'IP-IP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',1,NULL,'IP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',2,NULL,'IP6')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',3,NULL,'NSAP')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',4,NULL,'HDLC')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',5,NULL,'BBN')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',6,NULL,'IEEE-802')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',7,NULL,'E-163')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',8,NULL,'E-164')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',9,NULL,'F-69')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',10,NULL,'X-121')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',11,NULL,'IPX')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',12,NULL,'Appletalk')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',13,NULL,'Decnet4')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',14,NULL,'Vines')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Tunnel-Medium-Type',15,NULL,'E-164-NSAP')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'ARAP-Zone-Access',1,NULL,'Default-Zone')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'ARAP-Zone-Access',2,NULL,'Inclusive-Filter')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'ARAP-Zone-Access',3,NULL,'Exclusive-Filter')
go

INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Prompt',1,NULL,'No-Echo')
INSERT INTO MapValues (MapType,MapAttribute,RadValue,Description,Value) VALUES(1,'Prompt',2,NULL,'Echo')
go

CREATE PROCEDURE MapGetAttributes AS
SELECT MapAttribute,CASE WHEN RadVendorID = 0 THEN RadAttributeID ELSE RadVendorType END AS RadAttributeID,RadVendorID,MapType
FROM MapAttributes
go

CREATE PROCEDURE MapGetValues AS
SELECT MapAttribute,Value,RadValue,MapType
FROM MapValues
ORDER BY MapAttribute,MapType
go

CREATE PROCEDURE RadGetPoolConfigs (@AccountTypeID int, @ServerID int, @NASIdentifier varchar(16), @NASPort VARCHAR(10), @accountid INT, @callerid VARCHAR(20), @dnis VARCHAR(20)) AS
SET ROWCOUNT 1
SET NOCOUNT ON
DECLARE @ip VARCHAR(16)

UPDATE RadIPAddresses SET State = 0
	WHERE NASIdentifier = @NASIdentifier
	AND NASPort = @NASPort
	AND (State = 2
		OR (State = 1 AND LastUsed < DATEADD(mi,-2,getdate())))

Select @ip=ria.IPAddress
From ServerGroups sg, RadIPGroups rig, RadIPAddresses ria, RadIPAccountTypes riat, Servers s
Where s.ServerGroupID = sg.ServerGroupID
	and riat.ServerGroupID = sg.ServerGroupID
	AND riat.RadIPGroupID = rig.RadIPGroupID
	AND ria.RadIPGroupID = rig.RadIPGroupID
	and riat.AccountTypeID = @AccountTypeID
	and s.ServerID = @ServerID
	and State = 0
Order By ria.State, ria.LastUsed

IF @ip IS NULL
BEGIN
Select @ip=ria.IPAddress
From ServerGroups sg, RadIPGroups rig, RadIPAddresses ria, RadIPAccountTypes riat, Servers s
Where s.ServerGroupID = sg.ServerGroupID
	AND riat.ServerGroupID = sg.ServerGroupID
	AND riat.RadIPGroupID *= rig.RadIPGroupID
	AND ria.RadIPGroupID *= rig.RadIPGroupID
	and riat.AccountTypeID = @AccountTypeID
	AND s.ServerID = @ServerID
	AND State = 0
Order By ria.State, ria.LastUsed
END

IF @ip IS NULL
BEGIN
Select @ip=ria.IPAddress
From ServerGroups sg, RadIPGroups rig, RadIPAddresses ria, RadIPAccountTypes riat, Servers s
Where s.ServerGroupID = sg.ServerGroupID
	AND riat.ServerGroupID = sg.ServerGroupID
	AND riat.RadIPGroupID *= rig.RadIPGroupID
	AND ria.RadIPGroupID *= rig.RadIPGroupID
	and (riat.AccountTypeID = @AccountTypeID OR riat.AccountTypeID IS NULL)
	AND s.ServerID = @ServerID
	AND State = 0
Order By ria.State, ria.LastUsed
END

IF @ip IS NOT NULL
	BEGIN
	Update RadIPAddresses
		Set State = 1, NASIdentifier = @NASIdentifier, NASPort = @NASPort
		Where IPAddress = @ip

	Select 8 as AttributeID,0 as VendorID, 0 as Value, @ip as Data
	END
GO

CREATE PROCEDURE RadSetTimeLeft (@accountid INT, @login VARCHAR(32), @timeused INT) AS
DECLARE @aid INT
IF @accountid IS NULL
BEGIN
SELECT @aid = AccountID FROM SubAccounts WHERE Login = @login OR Email = @login
END ELSE BEGIN
SELECT @aid = @accountid
END

IF @aid IS NOT NULL
BEGIN
UPDATE SubAccounts SET TimeLeft = TimeLeft - ((@timeused + (60 - (@timeused % 60))) / 60) WHERE AccountID = @aid
SELECT TimeLeft * 60 FROM SubAccounts WHERE AccountID = @aid
END
go

CREATE PROCEDURE RadOnlineGetSNMP AS
SELECT s.IPAddress, st.SNMPType AS ServerType, s.Community, sp.SNMPUser, sp.AcctSessionID, sp.UserName, sp.ServerID,sp.Port
FROM Servers s, ServerPorts sp, ServerTypes st
	WHERE s.ServerID = sp.ServerID
	AND s.ServerType = st.ServerType
	AND AcctStatusType=1
	AND DATALENGTH(sp.SNMPUser) > 5
	AND DATALENGTH(s.Community) > 1
	AND UserName IS NOT NULL
ORDER BY sp.Port
go

CREATE PROCEDURE RadOnlineUpdateSNMP @serverid INT, @port INT, @username VARCHAR(32) AS
UPDATE ServerPorts SET AcctStatusType = 0
	WHERE AcctStatusType = 1 
	AND ServerID = @serverid
	AND Port = @port
	AND UserName = @username
SELECT CASE WHEN @@rowcount = 0 THEN 'Not Updated' ELSE 'Updated' END AS Status
go


