-- Radius 2.5 Upgrade.  Please note this will only run against a Radius 2.5 or 3.0 db.  If your using RadiusNT/X 
-- with another vendors database schema *DO NOT* run this script.

-- This script assumes the source (Existing Radius 2.5 or 3.0 database) is labled RadiusNT
-- Substitute all occurances of RadiusNT.. with mydb.. where 'mydb' is the name of your Radius 2.5 or 3.0 database.
-- You must run this script from an empty Radius4 database and an existing Radius 2.5 or 3.0 database.

IF ((SELECT COUNT(*) FROM SubAccounts) < 2)
BEGIN
DELETE FROM SubAccounts
DELETE FROM MasterAccounts
END

DELETE FROM RadATConfigs
go

DELETE FROM AccountTypes
go

IF EXISTS (SELECT * FROM RadiusNT..sysobjects so, RadiusNT..syscolumns sc
	WHERE so.id = sc.id
	AND so.name = 'AccountTypes'
	AND sc.name = 'DNISGroupID')

EXEC('	INSERT INTO AccountTypes (AccountType, DNISGroupID, Description)
	SELECT AccountType, DNISGroupID, Description 
	FROM RadiusNT..AccountTypes')
ELSE
EXEC('	INSERT INTO AccountTypes (AccountType, Description)
	SELECT AccountType, Description 
	FROM RadiusNT..AccountTypes')

DELETE FROM ServerPorts
DELETE FROM Servers
go

SET IDENTITY_INSERT Servers ON
IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
IF EXISTS (SELECT * FROM RadiusNT..sysobjects so, RadiusNT..syscolumns sc
	WHERE so.id = sc.id
	AND so.name = 'Servers'
	AND sc.name = 'Comments')
EXEC('INSERT INTO Servers (Comments, IPAddress, RadRoamServerID, Secret, Server, ServerID)
	SELECT Comments, IPAddress, RadRoamServerID, Secret, Server, ServerID 
	FROM RadiusNT..Servers')
ELSE
EXEC('INSERT INTO Servers (IPAddress, RadRoamServerID, Secret, Server, ServerID)
	SELECT IPAddress, RadRoamServerID, Secret, Server, ServerID 
	FROM RadiusNT..Servers')
ELSE
EXEC('
	INSERT INTO Servers (Comments, Community, IPAddress, RadRoamServerID, Secret, Server, ServerID)
	SELECT Comments, Community, IPAddress, RadRoamServerID, Secret, Server, ServerID 
	FROM RadiusNT..Servers
')
SET IDENTITY_INSERT Servers OFF
go

IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
	INSERT INTO ServerPorts (NASIdentifier, AcctStatusType, CallDate, FramedAddress, IPAddress, MaxSessionTime, Port, ServerID, UserName)
	SELECT s.IPAddress, sp.AcctStatusType, sp.CallDate, sp.FramedAddress, sp.IPAddress, sp.MaxSessionTime, sp.Port, sp.ServerID, sp.UserName
	FROM RadiusNT..ServerPorts sp, RadiusNT..Servers s
		WHERE sp.ServerID = s.ServerID
		AND EXISTS (SELECT ServerID FROM RadiusNT..ServerPorts sp2 WHERE sp2.ServerID = sp.ServerID AND sp2.Port = sp.Port GROUP BY ServerID,Port HAVING COUNT(Port) = 1)
ELSE
EXEC('	INSERT INTO ServerPorts (AccountID, NASIdentifier, AcctSessionID, AcctStatusType, CallDate, CallerID, ConnectInfo, FramedAddress, IPAddress, MaxSessionTime, Port, SNMPUser, ServerID, UserName)
	SELECT sp.AccountID, s.IPAddress, sp.AcctSessionID, sp.AcctStatusType, sp.CallDate, sp.CallerID, sp.ConnectInfo, sp.FramedAddress, sp.IPAddress, sp.MaxSessionTime, sp.Port, sp.SNMPUser, sp.ServerID, sp.UserName 
	FROM RadiusNT..ServerPorts sp, RadiusNT..Servers s
		WHERE sp.ServerID = s.ServerID
')
go

IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
	INSERT INTO Calls (AcctDelayTime, AcctSessionID, AcctSessionTime, AcctStatusType, AcctTerminateCause, CallDate, FramedAddress, NASIdentifier, NASPort, UserName)
	SELECT AcctDelayTime, AcctSessionID, AcctSessionTime, AcctStatusType, AcctTerminateCause, CallDate, FramedAddress, NASIdentifier, NASPort, UserName
	FROM RadiusNT..Calls
ELSE
EXEC('	INSERT INTO Calls (AccountID, AcctDelayTime, AcctSessionID, AcctSessionTime, AcctStatusType, AcctTerminateCause, CallDate, CallerID, ConnectInfo, FramedAddress, NASIdentifier, NASPort, ServerID, UserName)
	SELECT AccountID, AcctDelayTime, AcctSessionID, AcctSessionTime, AcctStatusType, AcctTerminateCause, CallDate, CallerID, ConnectInfo, FramedAddress, NASIdentifier, NASPort, ServerID, UserName 
	FROM RadiusNT..Calls
')
go

SET IDENTITY_INSERT DNISGroups ON
INSERT INTO DNISGroups (DNISGroup, DNISGroupID, Description)
SELECT DNISGroup, DNISGroupID, Description 
FROM RadiusNT..DNISGroups
SET IDENTITY_INSERT DNISGroups OFF
go

INSERT INTO DNISNumbers (DNISGroupID, DNISNumber)
SELECT DNISGroupID, DNISNumber 
FROM RadiusNT..DNISNumbers
go

DELETE FROM SubAccounts
DELETE FROM MasterAccounts
go

SET IDENTITY_INSERT MasterAccounts ON
IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
	INSERT INTO MasterAccounts (Active, CustomerID, FirstName, LastName, OverDue)
	SELECT Active, CustomerID, CONVERT(VARCHAR(25),FirstName), CONVERT(VARCHAR(25),LastName), OverDue
	FROM RadiusNT..MasterAccounts
ELSE
EXEC('	INSERT INTO MasterAccounts (Active, CustomerID, FirstName, LastModifyDate, LastName, OverDue)
	SELECT Active, CustomerID, FirstName, LastModifyDate, LastName, OverDue 
	FROM RadiusNT..MasterAccounts
')
SET IDENTITY_INSERT MasterAccounts OFF
go

SET IDENTITY_INSERT RadATConfigs ON
INSERT INTO RadATConfigs (AccountTypeID, Data, RadATConfigID, RadAttributeID, RadCheck, RadVendorID, RadVendorType, Value)
SELECT at1.AccountTypeID, Data, RadATConfigID, RadAttributeID, RadCheck, COALESCE(RadVendorID,0), COALESCE(RadVendorType,0), Value 
FROM RadiusNT..RadATConfigs rac, AccountTypes at1
	WHERE rac.AccountType = at1.AccountType
SET IDENTITY_INSERT RadATConfigs OFF
go

IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
	INSERT INTO RadLogs (Data, LogDate, RadLogMsgID, UserName)
	SELECT CONVERT(VARCHAR(50),Data), LogDate, RadLogMsgID, CONVERT(VARCHAR(40),Username)
	FROM RadiusNT..RadLogs rl
	WHERE EXISTS (SELECT LogDate FROM RadiusNT..RadLogs rl2 WHERE rl2.RadLogMsgID = rl.RadLogMsgID AND rl2.LogDate = rl.LogDate AND rl2.UserName = rl.Username GROUP BY RadLogMsgID,LogDate,Username HAVING COUNT(LogDate) = 1)
ELSE
EXEC('	INSERT INTO RadLogs (CallerID, Data, LogDate, NASIdentifier, NASPort, RadLogMsgID, UserName)
	SELECT CallerID, Data, LogDate, NASIdentifier, NASPort, RadLogMsgID, Username 
	FROM RadiusNT..RadLogs
')
go

SET IDENTITY_INSERT RadRoamDomains ON
INSERT INTO RadRoamDomains (AccountTypeID, Domain, Priority, RadRoamDomainID, RadRoamServerID)
SELECT at1.AccountTypeID, Domain, Priority, RadRoamDomainID, RadRoamServerID 
FROM RadiusNT..RadRoamDomains rd, AccountTypes at1
	WHERE rd.AccountType = at1.AccountType
SET IDENTITY_INSERT RadRoamDomains OFF
go

SET IDENTITY_INSERT RadRoamServers ON
INSERT INTO RadRoamServers (AcctPort, AuthPort, IPAddress, RadRoamServerID, Retries, Secret, Server, StripDomain, Timeout, TreatAsLocal)
SELECT AcctPort, AuthPort, IPAddress, RadRoamServerID, Retries, Secret, Server, StripDomain, Timeout, TreatAsLocal 
FROM RadiusNT..RadRoamServers
SET IDENTITY_INSERT RadRoamServers OFF
go

SET IDENTITY_INSERT RadTriggers ON
INSERT INTO RadTriggers (AccountID, Directory, FileName, Parameters, RadTriggerID, TriggerType)
SELECT AccountID, Directory, FileName, Parameters, RadTriggerID, Type 
FROM RadiusNT..RadTriggers
SET IDENTITY_INSERT RadTriggers OFF
go

IF object_id('RadiusNT..ServerAccess') IS NOT NULL
EXEC('	INSERT INTO ServerAccess (AccountTypeID, MaxSessionLength, Port, ServerID, StartTime, StopTime)
	SELECT at1.AccountTypeID, MaxSessionLength, Port, ServerID, StartTime, StopTime 
	FROM RadiusNT..ServerAccess sa, AccountTypes at1
		WHERE sa.AccountType = at1.AccountType')
go

SET IDENTITY_INSERT SubAccounts ON
IF object_id('RadiusNT..RadProxyAttributeGroups') IS NULL
	INSERT INTO SubAccounts (AccountID, AccountTypeID, Active, CustomerID, Email, Extension, FirstName, LastName, Login, LoginLimit, Password, TimeLeft, ExpireDate)
	SELECT sa.AccountID, at1.AccountTypeID, sa.Active, sa.CustomerID, sa.Email, ma.Extension, sa.FirstName, sa.LastName, sa.Login, sa.LoginLimit, sa.Password, sa.TimeLeft, ma.maExpireDate 
	FROM RadiusNT..SubAccounts sa, AccountTypes at1, RadiusNT..MasterAccounts ma
		WHERE sa.AccountType = at1.AccountType
		AND ma.customerID = sa.CustomerID
ELSE
EXEC('	INSERT INTO SubAccounts (AccountID, AccountTypeID, Active, CustomerID, Email, Extension, FirstName, LastModifyDate, LastName, LastUsed, Login, LoginLimit, Password, TimeLeft, ExpireDate)
	SELECT sa.AccountID, at1.AccountTypeID, sa.Active, sa.CustomerID, sa.Email, ma.Extension, sa.FirstName, sa.LastModifyDate, sa.LastName, sa.LastUsed, sa.Login, sa.LoginLimit, sa.Password, sa.TimeLeft, ma.maExpireDate
	FROM RadiusNT..SubAccounts sa, AccountTypes at1, RadiusNT..MasterAccounts ma
		WHERE sa.AccountType = at1.AccountType
		AND ma.CustomerID = sa.CustomerID
')
SET IDENTITY_INSERT SubAccounts OFF
go

INSERT INTO RadConfigs (AccountID, Data, RadAttributeID, RadCheck, RadVendorID, RadVendorType, Value)
SELECT AccountID, Data, RadAttributeID, RadCheck, COALESCE(RadVendorID,0), COALESCE(RadVendorType,0), Value 
FROM RadiusNT..RadConfigs
go

-- Radius 3.0
IF object_id('RadProxyAttributeGroups') IS NULL
BEGIN
EXEC('
SET IDENTITY_INSERT RadProxyAttributeGroups ON
INSERT INTO RadProxyAttributeGroups (Description, Priority, RadProxyAttributeGroupID, RadRoamServerID)
SELECT Description, Priority, RadProxyAttributeGroupID, RadRoamServerID 
FROM RadiusNT..RadProxyAttributeGroups
SET IDENTITY_INSERT RadProxyAttributeGroups OFF

SET IDENTITY_INSERT RadProxyAttributes ON
INSERT INTO RadProxyAttributes (RadAttributeID, RadProxyAttributeGroupID, RadProxyAttributeID, SearchType, String)
SELECT RadAttributeID, RadProxyAttributeGroupID, RadProxyAttributeID, SearchType, String 
FROM RadiusNT..RadProxyAttributes
SET IDENTITY_INSERT RadProxyAttributes OFF

SET IDENTITY_INSERT RadRejects ON
INSERT INTO RadRejects (Data, RadAttributeID, RadRejectID, RadVendorID, RadVendorType, Value)
SELECT Data, RadAttributeID, RadRejectID, RadVendorID, RadVendorType, Value 
FROM RadiusNT..RadRejects
SET IDENTITY_INSERT RadRejects OFF
')
END
go

